summaryrefslogtreecommitdiffstats
path: root/quanta/src/dtds.h
diff options
context:
space:
mode:
Diffstat (limited to 'quanta/src/dtds.h')
-rw-r--r--quanta/src/dtds.h29
1 files changed, 15 insertions, 14 deletions
diff --git a/quanta/src/dtds.h b/quanta/src/dtds.h
index 120157a8..ae7c28f1 100644
--- a/quanta/src/dtds.h
+++ b/quanta/src/dtds.h
@@ -34,7 +34,7 @@
class TQDomNode;
class TQDomDocument;
-class QTag;
+class TQTag;
class TQString;
class TQStringList;
class KConfig;
@@ -44,11 +44,12 @@ struct DTDStruct;
/** @short This class manages the DTD's for Quanta.
*
* The constructor only loads the necessary information from the description.rc file.
* The rest is later loaded on demand of the find() function.
*/
-class DTDs : public QObject
+class DTDs : public TQObject
{
Q_OBJECT
+ TQ_OBJECT
public:
@@ -56,10 +57,10 @@ public:
* since this class is a singleton you must use this function to access it
* @return the class pointer
*/
- static DTDs* ref(TQObject *parent = 0L)
+ static DTDs* ref(TQObject *tqparent = 0L)
{
static DTDs *m_ref;
- if (!m_ref) m_ref = new DTDs(parent);
+ if (!m_ref) m_ref = new DTDs(tqparent);
return m_ref;
}
@@ -72,10 +73,10 @@ public:
* @param dtdName name of the dtd, will be converted to lowercase inside
* @return the found dtd structure
*/
- const DTDStruct * find (const TQString &dtdName)
+ const DTDStruct * tqfind (const TQString &dtdName)
{
-// kdDebug(24000) << "dtds::find " << dtdName << endl;
- DTDStruct *dtd = m_dict->find(dtdName.lower()) ;
+// kdDebug(24000) << "dtds::tqfind " << dtdName << endl;
+ DTDStruct *dtd = m_dict->tqfind(dtdName.lower()) ;
if (dtd && ! dtd->loaded ) readTagDir2(dtd);
return dtd;
}
@@ -92,7 +93,7 @@ public:
*/
TQString getDTDNickNameFromName(const TQString& name)
{
- DTDStruct *dtd = m_dict->find(name);
+ DTDStruct *dtd = m_dict->tqfind(name);
if ( dtd )
return dtd->nickName;
else
@@ -178,7 +179,7 @@ private:
* If you need the class use DTDs::ref() for
* construction and reference
*/
- DTDs(TQObject *parent);
+ DTDs(TQObject *tqparent);
/** Reads the tag files and the description.rc from tagDir in order to
@@ -208,19 +209,19 @@ private:
/** Reads the tags from the tag files.
*
* @param fileName path of the tag file
* @param parentDTD the DTD where the tags belog to
* @param tagList the list where the tags are inserted
* @return the number of read tags.
*/
- uint readTagFile(const TQString& fileName, DTDStruct* parentDTD, QTagList *tagList);
+ uint readTagFile(const TQString& fileName, DTDStruct* tqparentDTD, TQTagList *tagList);
/** Parses the dom document and retrieve the tag attributes
*
* @param dom the DOM node containing the tag definition
* @param tag the QTag object that will be initialized by using the information in dom
* @param common will be true, if the tag is a just a list of common group attributes
*/
- void setAttributes(TQDomNode *dom, QTag* tag, bool &common);
+ void setAttributes(TQDomNode *dom, TQTag* tag, bool &common);
/** removes dtd from dictonary and deletes all components
*
* @param dtd the dtd to delete
@@ -44,11 +44,12 @@ struct DTDStruct;
*
* The constructor only loads the necessary information from the description.rc file.
- * The rest is later loaded on demand of the find() function.
+ * The rest is later loaded on demand of the tqfind() function.
*/
@@ -208,19 +209,19 @@ private:
*
* @param fileName path of the tag file
- * @param parentDTD the DTD where the tags belog to
+ * @param tqparentDTD the DTD where the tags belog to
* @param tagList the list where the tags are inserted
* @return the number of read tags.
@@ -208,19 +209,19 @@ private:
*
* @param dom the DOM node containing the tag definition
- * @param tag the QTag object that will be initialized by using the information in dom
+ * @param tag the TQTag object that will be initialized by using the information in dom
* @param common will be true, if the tag is a just a list of common group attributes
*/